@@ -36,6 +36,7 @@ The tuples can be of following format:
   extra in this case, the resulting name is `extra.[shadowkey]`. The
   `conversion_function` is optional. Logically equivalent to:
   `event[extra.`*intelmqkey*`] = conversion_function(row[`*shadowkey*`)]`.
+- `(False, 'shadowkey')`, the column will be ignored.
 
 Mappings are "straight forward" each mapping is a dict
 of at least three keys:
@@ -1577,8 +1578,8 @@ open_ldap = {
     }
 }
 
-# https://www.shadowserver.org/wiki/pmwiki.php/Services/Blacklist
-blacklisted_ip = {
+# https://www.shadowserver.org/what-we-do/network-reporting/blocklist-report/
+blocklist = {
     'required_fields': [
         ('time.source', 'timestamp', add_UTC_to_timestamp),
         ('source.ip', 'ip'),
@@ -2298,6 +2299,67 @@ accessible_ard = {
     }
 }
 
+# https://www.shadowserver.org/what-we-do/network-reporting/accessible-radmin-report/
+accessible_radmin = {
+    'required_fields': [
+        ('time.source', 'timestamp', add_UTC_to_timestamp),
+        ('source.ip', 'ip'),
+        ('source.port', 'port', convert_int),
+    ],
+    'optional_fields': [
+        ('source.asn', 'asn', convert_int),
+        # ('classification.identifier', 'tag'),  # always 'accessible-radmin' - set in constant_fields
+        ('source.geolocation.cc', 'geo'),
+        ('source.geolocation.region', 'region'),
+        ('source.geolocation.city', 'city'),
+        ('source.reverse_dns', 'hostname', validate_to_none),
+        ('protocol.transport', 'protocol'),
+        ('extra.', 'naics', convert_int),
+        ('extra.', 'version', validate_to_none),
+    ],
+    'constant_fields': {
+        'classification.identifier': 'accessible-radmin',
+        'classification.taxonomy': 'vulnerable',
+        'classification.type': 'vulnerable service',
+    }
+}
+
+# https://www.shadowserver.org/what-we-do/network-reporting/caida-ip-spoofer-report/
+# NOTE: The "type" field is included twice with the same values
+caida = {
+    'required_fields': [
+        ('time.source', 'timestamp', add_UTC_to_timestamp),
+        ('source.ip', 'ip'),
+    ],
+    'optional_fields': [
+        ('source.asn', 'asn', convert_int),
+        # ('classification.identifier', 'tag'),  # always 'ip-spoofer' - set in constant_fields
+        ('classification.identifier', 'infection'),
+        ('source.geolocation.cc', 'geo'),
+        ('source.geolocation.region', 'region'),
+        ('source.geolocation.city', 'city'),
+        ('source.reverse_dns', 'hostname', validate_to_none),
+        ('extra.', 'type', validate_to_none),
+        ('extra.', 'naics', convert_int),
+        ('extra.', 'sic', convert_int),
+        ('extra.', 'sector', validate_to_none),
+        # FIXME Is is mappable to some classification.* field? Not included in example data.
+        ('extra.', 'family', validate_to_none),
+        ('source.network', 'network', validate_to_none),
+        (False, 'version', validate_to_none),  # we can ignore the IP version, it's obvious fron the address
+        ('extra.', 'routedspoof', validate_to_none),
+        ('extra.', 'session', convert_int),
+        ('extra.', 'nat', convert_bool),
+        ('extra.', 'public_source', validate_to_none),
+    ],
+    'constant_fields': {
+        # FIXME Check if the classification is correct
+        'classification.identifier': 'ip-spoofer',
+        'classification.taxonomy': 'fraud',
+        'classification.type': 'masquerade',
+    }
+}
+
 mapping = (
     # feed name, file name, function
     ('Accessible-ADB', 'scan_adb', accessible_adb),
@@ -2309,6 +2371,7 @@ mapping = (
     ('Accessible-FTP', 'scan_ftp', accessible_ftp),
     ('Accessible-HTTP', 'scan_http', accessible_http),
     ('Accessible-Hadoop', 'scan_hadoop', accessible_hadoop),
+    ('Accessible-Radmin', 'scan_radmin', accessible_radmin),
     ('Accessible-RDP', 'scan_rdp', accessible_rdp),
     ('Accessible-Rsync', 'scan_rsync', accessible_rsync),
     ('Accessible-SMB', 'scan_smb', accessible_smb),
@@ -2316,7 +2379,9 @@ mapping = (
     ('Accessible-Ubiquiti-Discovery-Service', 'scan_ubiquiti', accessible_ubiquiti_discovery_service),
     ('Accessible-VNC', 'scan_vnc', accessible_vnc),
     ('Amplification-DDoS-Victim', 'ddos_amplification', amplification_ddos_victim),
-    ('Blacklisted-IP', 'blacklist', blacklisted_ip),
+    ('Blacklisted-IP', 'blacklist', blocklist),
+    ('Blocklist', 'blocklist', blocklist),
+    ('CAIDA-IP-Spoofer', 'caida_ip_spoofer', caida),
     ('Compromised-Website', 'compromised_website', compromised_website),
     ('DNS-Open-Resolvers', 'scan_dns', dns_open_resolvers),
     ('Darknet', 'darknet', darknet),
